@@ -75,7 +75,8 @@ def hanlp_releases(cache=True):
         return HANLP_RELEASES
     # print('Request GitHub API')
     req = urllib.Request('http://nlp.hankcs.com/download.php?file=version')
-    req.add_header('User-agent', 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/65.0.3325.162 Safari/537.36')
+    req.add_header('User-agent',
+                   'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_2) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/65.0.3325.162 Safari/537.36')
     if PY == 3:
         content = urllib.urlopen(req).read()
     else:
@@ -205,6 +206,8 @@ def install_hanlp_data(the_jar_version=None):
             data_zip = 'data-for-{}.zip'.format(data_version)
             data_zip = os.path.join(STATIC_ROOT, data_zip)
             download(data_url, os.path.join(STATIC_ROOT, data_zip))
+            sys.stderr.write('\r' + ' ' * 100 + '\r')  # 清理上一行
+            sys.stderr.flush()
             eprint('解压 data.zip...')
             try:
                 with zipfile.ZipFile(data_zip, "r") as zip_ref:
